LinqWherePseudoClass<TModelType, TDataType> class abstract

Constructors

LinqWherePseudoClass()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reverse<TReverseModelType>({Object? key}) LinqWherePseudoClass<TReverseModelType, TDataType>
toString() String
A string representation of this object.
inherited
whereField<TValueType>(String name) LinqWherePropertyField<TDataType, TValueType>

Operators

operator ==(Object other) bool
The equality operator.
inherited